ATAX provides classes and functions for doing simple accounting according to
Austrian tax laws.

ATAX is distributed under the conditions of the `BSD 3-Clause
License <http://www.c-tanzer.at/license/bsd_3c.html>`_.

ATAX is available as a `git repository`_.
You can clone that repository with::

    git clone git@github.com:Tapyr/tapyr.git

Reports of bugs in ATAX should be submitted to the `git repository`_.

.. _`git repository`: https://github.com/Tapyr/tapyr
